=== modified file 'lib/Controller/DisplayGroup.php'
--- lib/Controller/DisplayGroup.php	2016-03-17 09:15:05 +0000
+++ lib/Controller/DisplayGroup.php	2016-03-17 11:33:19 +0000
@@ -443,6 +443,8 @@
     public function add()
     {
         $displayGroup = $this->displayGroupFactory->createEmpty();
+        $displayGroup->setChildObjectDependencies($this->displayFactory, $this->layoutFactory, $this->mediaFactory, $this->scheduleFactory);
+
         $displayGroup->displayGroup = $this->getSanitizer()->getString('displayGroup');
         $displayGroup->description = $this->getSanitizer()->getString('description');
         $displayGroup->isDynamic = $this->getSanitizer()->getCheckbox('isDynamic');

=== modified file 'lib/Controller/Library.php'
--- lib/Controller/Library.php	2016-03-17 09:15:05 +0000
+++ lib/Controller/Library.php	2016-03-17 13:54:26 +0000
@@ -31,6 +31,7 @@
 use Xibo\Factory\ModuleFactory;
 use Xibo\Factory\PermissionFactory;
 use Xibo\Factory\PlaylistFactory;
+use Xibo\Factory\RegionFactory;
 use Xibo\Factory\TagFactory;
 use Xibo\Factory\UserFactory;
 use Xibo\Factory\UserGroupFactory;
@@ -102,6 +103,9 @@
     /** @var  DisplayGroupFactory */
     private $displayGroupFactory;
 
+    /** @var  RegionFactory */
+    private $regionFactory;
+
     /**
      * Set common dependencies.
      * @param LogServiceInterface $log
@@ -122,8 +126,9 @@
      * @param PlaylistFactory $playlistFactory
      * @param UserGroupFactory $userGroupFactory
      * @param DisplayGroupFactory $displayGroupFactory
+     * @param RegionFactory $regionFactory
      */
-    public function __construct($log, $sanitizerService, $state, $user, $help, $date, $config, $store, $userFactory, $moduleFactory, $tagFactory, $mediaFactory, $widgetFactory, $permissionFactory, $layoutFactory, $playlistFactory, $userGroupFactory, $displayGroupFactory)
+    public function __construct($log, $sanitizerService, $state, $user, $help, $date, $config, $store, $userFactory, $moduleFactory, $tagFactory, $mediaFactory, $widgetFactory, $permissionFactory, $layoutFactory, $playlistFactory, $userGroupFactory, $displayGroupFactory, $regionFactory)
     {
         $this->setCommonDependencies($log, $sanitizerService, $state, $user, $help, $date, $config);
 
@@ -138,6 +143,7 @@
         $this->playlistFactory = $playlistFactory;
         $this->userGroupFactory = $userGroupFactory;
         $this->displayGroupFactory = $displayGroupFactory;
+        $this->regionFactory = $regionFactory;
     }
 
     /**
@@ -204,6 +210,15 @@
     }
 
     /**
+     * Get RegionFactory
+     * @return RegionFactory
+     */
+    public function getRegionFactory()
+    {
+        return $this->regionFactory;
+    }
+
+    /**
      * Displays the page logic
      */
     function displayPage()

=== modified file 'lib/Controller/Module.php'
--- lib/Controller/Module.php	2016-03-08 17:24:15 +0000
+++ lib/Controller/Module.php	2016-03-17 13:54:26 +0000
@@ -22,6 +22,8 @@
 
 use Xibo\Entity\Permission;
 use Xibo\Exception\AccessDeniedException;
+use Xibo\Factory\DisplayGroupFactory;
+use Xibo\Factory\LayoutFactory;
 use Xibo\Factory\MediaFactory;
 use Xibo\Factory\ModuleFactory;
 use Xibo\Factory\PermissionFactory;
@@ -87,6 +89,12 @@
      */
     private $regionFactory;
 
+    /** @var  LayoutFactory */
+    protected $layoutFactory;
+
+    /** @var  DisplayGroupFactory */
+    protected $displayGroupFactory;
+
     /**
      * Set common dependencies.
      * @param LogServiceInterface $log
@@ -96,7 +104,7 @@
      * @param \Xibo\Service\HelpServiceInterface $help
      * @param DateServiceInterface $date
      * @param ConfigServiceInterface $config
-     * @oaram StorageServiceInterface $store
+     * @param StorageServiceInterface $store
      * @param ModuleFactory $moduleFactory
      * @param PlaylistFactory $playlistFactory
      * @param MediaFactory $mediaFactory
@@ -105,8 +113,10 @@
      * @param WidgetFactory $widgetFactory
      * @param TransitionFactory $transitionFactory
      * @param RegionFactory $regionFactory
+     * @param LayoutFactory $layoutFactory
+     * @param DisplayGroupFactory $displayGroupFactory
      */
-    public function __construct($log, $sanitizerService, $state, $user, $help, $date, $config, $store, $moduleFactory, $playlistFactory, $mediaFactory, $permissionFactory, $userGroupFactory, $widgetFactory, $transitionFactory, $regionFactory)
+    public function __construct($log, $sanitizerService, $state, $user, $help, $date, $config, $store, $moduleFactory, $playlistFactory, $mediaFactory, $permissionFactory, $userGroupFactory, $widgetFactory, $transitionFactory, $regionFactory, $layoutFactory, $displayGroupFactory)
     {
         $this->setCommonDependencies($log, $sanitizerService, $state, $user, $help, $date, $config);
 
@@ -119,6 +129,8 @@
         $this->widgetFactory = $widgetFactory;
         $this->transitionFactory = $transitionFactory;
         $this->regionFactory = $regionFactory;
+        $this->layoutFactory = $layoutFactory;
+        $this->displayGroupFactory = $displayGroupFactory;
     }
 
     /**
@@ -471,6 +483,9 @@
         if (!$this->getUser()->checkDeleteable($module->widget))
             throw new AccessDeniedException();
 
+        // Set some dependencies that are used in the delete
+        $module->setChildObjectDependencies($this->layoutFactory, $this->widgetFactory, $this->displayGroupFactory);
+
         // Pass to view
         $this->getState()->template = 'module-form-delete';
         $this->getState()->setData([
@@ -490,6 +505,9 @@
         if (!$this->getUser()->checkDeleteable($module->widget))
             throw new AccessDeniedException();
 
+        // Set some dependencies that are used in the delete
+        $module->setChildObjectDependencies($this->layoutFactory, $this->widgetFactory, $this->displayGroupFactory);
+
         $moduleName = $module->getName();
         $widgetMedia = $module->widget->mediaIds;
 
@@ -511,6 +529,8 @@
                 if (!$this->getUser()->checkDeleteable($media))
                     throw new AccessDeniedException();
 
+                $media->setChildObjectDependencies($this->layoutFactory, $this->widgetFactory, $this->displayGroupFactory);
+
                 $media->delete();
             }
         }

=== modified file 'lib/Controller/Playlist.php'
--- lib/Controller/Playlist.php	2016-03-08 17:24:15 +0000
+++ lib/Controller/Playlist.php	2016-03-18 09:52:11 +0000
@@ -82,19 +82,21 @@
      * @param ConfigServiceInterface $config
      * @param PlaylistFactory $playlistFactory
      * @param RegionFactory $regionFactory
+     * @param MediaFactory $mediaFactory
      * @param PermissionFactory $permissionFactory
      * @param TransitionFactory $transitionFactory
      * @param WidgetFactory $widgetFactory
      * @param ModuleFactory $moduleFactory
      * @param UserGroupFactory $userGroupFactory
      */
-    public function __construct($log, $sanitizerService, $state, $user, $help, $date, $config, $playlistFactory, $regionFactory, $permissionFactory,
+    public function __construct($log, $sanitizerService, $state, $user, $help, $date, $config, $playlistFactory, $regionFactory, $mediaFactory, $permissionFactory,
         $transitionFactory, $widgetFactory, $moduleFactory, $userGroupFactory)
     {
         $this->setCommonDependencies($log, $sanitizerService, $state, $user, $help, $date, $config);
 
         $this->playlistFactory = $playlistFactory;
         $this->regionFactory = $regionFactory;
+        $this->mediaFactory = $mediaFactory;
         $this->permissionFactory = $permissionFactory;
         $this->transitionFactory = $transitionFactory;
         $this->widgetFactory = $widgetFactory;
@@ -180,6 +182,7 @@
             throw new AccessDeniedException();
 
         $playlist->name = $this->getSanitizer()->getString('name');
+        $playlist->setChildObjectDependencies($this->regionFactory);
         $playlist->save();
 
         // Success
@@ -204,6 +207,8 @@
         if (!$this->getUser()->checkDeleteable($playlist))
             throw new AccessDeniedException();
 
+        $playlist->setChildObjectDependencies($this->regionFactory);
+
         // Issue the delete
         $playlist->delete();
 
@@ -378,6 +383,8 @@
         if (!$this->getUser()->checkEditable($playlist))
             throw new AccessDeniedException();
 
+        $playlist->setChildObjectDependencies($this->regionFactory);
+
         // Expect a list of mediaIds
         $media = $this->getSanitizer()->getIntArray('media');
 
@@ -484,6 +491,7 @@
             throw new AccessDeniedException();
 
         // Load the widgets
+        $playlist->setChildObjectDependencies($this->regionFactory);
         $playlist->load();
 
         // Get our list of widget orders

=== modified file 'lib/Controller/Schedule.php'
--- lib/Controller/Schedule.php	2016-03-14 12:16:22 +0000
+++ lib/Controller/Schedule.php	2016-03-17 13:45:09 +0000
@@ -731,6 +731,7 @@
         if (!$this->isEventEditable($schedule->displayGroups))
             throw new AccessDeniedException();
 
+        $schedule->setChildObjectDependencies($this->displayFactory, $this->layoutFactory, $this->mediaFactory, $this->scheduleFactory);
         $schedule->delete();
 
         // Return

=== modified file 'lib/Entity/DisplayProfile.php'
--- lib/Entity/DisplayProfile.php	2016-03-15 13:39:52 +0000
+++ lib/Entity/DisplayProfile.php	2016-03-18 10:55:44 +0000
@@ -416,7 +416,7 @@
                         'title' => __('Enable stats reporting?'),
                         'type' => 'checkbox',
                         'fieldType' => 'checkbox',
-                        'default' => $this->configService->getThemeConfig('client_statsEnabled_default', 1),
+                        'default' => $this->configService->getThemeConfig('client_statsEnabled_default', 0),
                         'helpText' => __('Should the application send proof of play stats to the CMS.'),
                         'enabled' => true,
                         'groupClass' => NULL
@@ -780,7 +780,7 @@
                         'title' => __('Enable stats reporting?'),
                         'type' => 'checkbox',
                         'fieldType' => 'checkbox',
-                        'default' => $this->configService->getThemeConfig('client_statsEnabled_default', 1),
+                        'default' => $this->configService->getThemeConfig('client_statsEnabled_default', 0),
                         'helpText' => __('Should the application send proof of play stats to the CMS.'),
                         'enabled' => true,
                         'groupClass' => NULL
@@ -968,6 +968,17 @@
                         'groupClass' => NULL
                     ),
                     array(
+                        'name' => 'screenShotSize',
+                        'tabId' => 'advanced',
+                        'title' => __('Screen Shot Size'),
+                        'type' => 'int',
+                        'fieldType' => 'number',
+                        'default' => $this->configService->getThemeConfig('client_screenShotSize_default', 200),
+                        'helpText' => __('The size of the largest dimension. Empty or 0 means the screen size.'),
+                        'enabled' => true,
+                        'groupClass' => NULL
+                    ),
+                    array(
                         'name' => 'updateStartWindow',
                         'tabId' => 'advanced',
                         'title' => __('Update Window Start Time'),

=== modified file 'lib/Entity/Layout.php'
--- lib/Entity/Layout.php	2016-03-11 15:44:46 +0000
+++ lib/Entity/Layout.php	2016-03-18 10:55:44 +0000
@@ -649,6 +649,8 @@
      */
     public function toXlf()
     {
+        $this->getLog()->debug('Layout toXLF for Layout %s, %d', $this->layout, $this->layoutId);
+
         $this->load(['loadPlaylists' => true]);
 
         $document = new \DOMDocument();
@@ -684,6 +686,7 @@
         //  5. In either case, add the duration from #4 to the region duration
 
         $layoutHasRegionControllingDuration = false;
+        $layoutHasEmptyRegion = false;
 
         foreach ($this->regions as $region) {
             /* @var Region $region */
@@ -702,14 +705,20 @@
                 }
             }
 
+            // Record whether there is an empty region
+            if ($countWidgets <= 0)
+                $layoutHasEmptyRegion = true;
+
             // Any with more than one widget
             // Any with duration specified?
             if ($countWidgets > 1 || $hasDuration) {
                 $layoutHasRegionControllingDuration = true;
-                break;
             }
         }
 
+        if ($layoutHasEmptyRegion)
+            $this->getLog()->alert('Layout has empty region');
+
         foreach ($this->regions as $region) {
             /* @var Region $region */
             $regionNode = $document->createElement('region');
@@ -851,6 +860,9 @@
         $layoutNode->appendChild($tagsNode);
 
         // Update the layout status / duration accordingly
+        if ($layoutHasEmptyRegion)
+            $status = 4;
+
         $this->status = ($status < $this->status) ? $status : $this->status;
 
         return $document->saveXML();
@@ -917,10 +929,15 @@
 
     /**
      * Save the XLF to disk
+     * @param array $options
      * @return string the path
      */
-    public function xlfToDisk()
+    public function xlfToDisk($options = [])
     {
+        $options = array_merge([
+            'notify' => true
+        ], $options);
+
         $path = $this->getCachePath();
 
         if ($this->status == 3 || !file_exists($path)) {
@@ -941,7 +958,8 @@
                 'saveRegionOptions' => false,
                 'manageRegionAssignments' => false,
                 'saveTags' => false,
-                'setBuildRequired' => false
+                'setBuildRequired' => false,
+                'notify' => $options['notify']
             ]);
         }
 

=== modified file 'lib/Entity/Schedule.php'
--- lib/Entity/Schedule.php	2016-03-09 14:53:58 +0000
+++ lib/Entity/Schedule.php	2016-03-17 13:45:09 +0000
@@ -399,6 +399,9 @@
      */
     public function delete()
     {
+        // Notify display groups
+        $notify = $this->displayGroups;
+
         // Delete display group assignments
         $this->displayGroups = [];
         $this->unlinkDisplayGroups();
@@ -408,6 +411,21 @@
 
         // Delete the event itself
         $this->getStore()->update('DELETE FROM `schedule` WHERE eventId = :eventId', ['eventId' => $this->eventId]);
+
+        // Check the main event dates to see if we are in the schedule look ahead
+        $this->isInScheduleLookAhead = $this->datesInScheduleLookAhead($this->fromDt, $this->toDt);
+
+        // Notify
+        // Only if the schedule effects the immediate future - i.e. within the RF Look Ahead
+        if ($this->isInScheduleLookAhead) {
+            $this->getLog()->debug('Schedule changing is within the schedule look ahead, will notify %d display groups', $this->displayGroups);
+            foreach ($notify as $displayGroup) {
+                /* @var DisplayGroup $displayGroup */
+                $displayGroup->setChildObjectDependencies($this->displayFactory, $this->layoutFactory, $this->mediaFactory, $this->scheduleFactory);
+                $displayGroup->setCollectRequired();
+                $displayGroup->setMediaIncomplete();
+            }
+        }
     }
 
     /**

=== modified file 'lib/Factory/BaseFactory.php'
--- lib/Factory/BaseFactory.php	2016-03-16 19:55:47 +0000
+++ lib/Factory/BaseFactory.php	2016-03-17 12:24:38 +0000
@@ -155,7 +155,7 @@
         else {
             $user = $this->getUser();
 
-            $this->getLog()->debug('Checking permissions against a the logged in user: %d, %s, %d', $user->userId, $user->userName, $user->userTypeId);
+            $this->getLog()->debug('Checking permissions against the logged in user: ID: %d, Name: %s, UserType: %d', $user->userId, $user->userName, $user->userTypeId);
         }
 
         $permissionSql = '';

=== modified file 'lib/Factory/CampaignFactory.php'
--- lib/Factory/CampaignFactory.php	2016-03-07 17:33:10 +0000
+++ lib/Factory/CampaignFactory.php	2016-03-17 15:30:45 +0000
@@ -143,7 +143,7 @@
     public function query($sortOrder = null, $filterBy = array())
     {
         if ($sortOrder == null)
-            $sortOrder = array('Campaign');
+            $sortOrder = array('campaign');
 
         $campaigns = array();
         $params = array();
@@ -213,6 +213,15 @@
             }
         }
 
+        // Exclude templates by default
+        if ($this->getSanitizer()->getInt('excludeTemplates', 1, $filterBy) != -1) {
+            if ($this->getSanitizer()->getInt('excludeTemplates', 1, $filterBy) == 1) {
+                $body .= " AND `campaign`.campaignId NOT IN (SELECT `campaignId` FROM `lkcampaignlayout` WHERE layoutId IN (SELECT layoutId FROM lktaglayout WHERE tagId = 1)) ";
+            } else {
+                $body .= " AND `campaign`.campaignId IN (SELECT `campaignId` FROM `lkcampaignlayout` WHERE layoutId IN (SELECT layoutId FROM lktaglayout WHERE tagId = 1)) ";
+            }
+        }
+
         $group = 'GROUP BY `campaign`.CampaignID, Campaign, IsLayoutSpecific, `campaign`.userId ';
 
         // Sorting?

=== modified file 'lib/Factory/WidgetFactory.php'
--- lib/Factory/WidgetFactory.php	2016-03-09 13:21:23 +0000
+++ lib/Factory/WidgetFactory.php	2016-03-17 12:24:38 +0000
@@ -23,6 +23,7 @@
 namespace Xibo\Factory;
 
 
+use Xibo\Entity\User;
 use Xibo\Entity\Widget;
 use Xibo\Exception\NotFoundException;
 use Xibo\Service\DateServiceInterface;
@@ -60,15 +61,18 @@
      * @param StorageServiceInterface $store
      * @param LogServiceInterface $log
      * @param SanitizerServiceInterface $sanitizerService
+     * @param User $user
+     * @param UserFactory $userFactory
      * @param DateServiceInterface $date
      * @param WidgetOptionFactory $widgetOptionFactory
      * @param WidgetMediaFactory $widgetMediaFactory
      * @param PermissionFactory $permissionFactory
      *
      */
-    public function __construct($store, $log, $sanitizerService, $date, $widgetOptionFactory, $widgetMediaFactory, $permissionFactory)
+    public function __construct($store, $log, $sanitizerService, $user, $userFactory, $date, $widgetOptionFactory, $widgetMediaFactory, $permissionFactory)
     {
         $this->setCommonDependencies($store, $log, $sanitizerService);
+        $this->setAclDependencies($user, $userFactory);
         $this->dateService = $date;
         $this->widgetOptionFactory = $widgetOptionFactory;
         $this->widgetMediaFactory = $widgetMediaFactory;

=== modified file 'lib/Factory/WidgetMediaFactory.php'
--- lib/Factory/WidgetMediaFactory.php	2016-03-04 17:53:25 +0000
+++ lib/Factory/WidgetMediaFactory.php	2016-03-17 12:24:38 +0000
@@ -58,7 +58,7 @@
      */
     public function query($sortOrder = null, $filterBy = null)
     {
-        $sql = 'SELECT mediaId FROM `lkwidgetmedia` WHERE widgetId = :widgetId';
+        $sql = 'SELECT mediaId FROM `lkwidgetmedia` WHERE widgetId = :widgetId AND mediaId <> 0 ';
 
         return array_map(function($element) { return $element['mediaId']; }, $this->getStore()->select($sql, array('widgetId' => $this->getSanitizer()->getInt('widgetId', $filterBy))));
     }

=== modified file 'lib/Helper/XiboUploadHandler.php'
--- lib/Helper/XiboUploadHandler.php	2016-03-08 13:07:28 +0000
+++ lib/Helper/XiboUploadHandler.php	2016-03-17 13:54:26 +0000
@@ -212,6 +212,7 @@
 
                 // Get the Playlist
                 $playlist = $controller->getPlaylistFactory()->getById($this->options['playlistId']);
+                $playlist->setChildObjectDependencies($controller->getRegionFactory());
 
                 // Create a Widget and add it to our region
                 $widget = $controller->getWidgetFactory()->create($this->options['userId'], $playlist->playlistId, $module->getModuleType(), $media->duration);

=== modified file 'lib/Middleware/SAMLAuthentication.php'
--- lib/Middleware/SAMLAuthentication.php	2016-03-16 19:55:47 +0000
+++ lib/Middleware/SAMLAuthentication.php	2016-03-18 07:38:35 +0000
@@ -24,6 +24,7 @@
 
 
 use Slim\Middleware;
+use Xibo\Entity\User;
 use Xibo\Exception\AccessDeniedException;
 use Xibo\Exception\NotFoundException;
 use Xibo\Helper\ApplicationState;
@@ -169,7 +170,10 @@
                         throw new AccessDeniedException(__('User logged at the IdP but the account does not exist in the CMS and Just-In-Time provisioning is disabled'));
                     } else {
                         // Provision the user
+                        /** @var User $user */
                         $user = $app->userFactory->create();
+                        $user->setChildAclDependencies($app->userGroupFactory, $app->pageFactory);
+
                         if (isset($userData["UserName"])) {
                             $user->userName = $userData["UserName"][0];
                         }

=== modified file 'lib/Middleware/State.php'
--- lib/Middleware/State.php	2016-03-16 12:08:43 +0000
+++ lib/Middleware/State.php	2016-03-18 09:52:11 +0000
@@ -193,10 +193,12 @@
 
         // Configure logging
         if (strtolower($mode) == 'test') {
-            $app->config('log.level', \Slim\Log::DEBUG);
+            error_reporting(E_ALL);
+            ini_set('display_errors', 1);
+            $app->getLog()->setLevel(\Slim\Log::DEBUG);
         }
         else {
-            $app->config('log.level', \Xibo\Service\LogService::resolveLogLevel($app->configService->GetSetting('audit', 'error')));
+            $app->getLog()->setLevel(\Xibo\Service\LogService::resolveLogLevel($app->configService->GetSetting('audit')));
         }
 
         // Configure any extra log handlers
@@ -551,7 +553,8 @@
                 $container->layoutFactory,
                 $container->playlistFactory,
                 $container->userGroupFactory,
-                $container->displayGroupFactory
+                $container->displayGroupFactory,
+                $container->regionFactory
             );
         });
 
@@ -633,7 +636,9 @@
                 $container->userGroupFactory,
                 $container->widgetFactory,
                 $container->transitionFactory,
-                $container->regionFactory
+                $container->regionFactory,
+                $container->layoutFactory,
+                $container->displayGroupFactory
             );
         });
 
@@ -648,6 +653,7 @@
                 $container->configService,
                 $container->playlistFactory,
                 $container->regionFactory,
+                $container->mediaFactory,
                 $container->permissionsFactory,
                 $container->transitionFactory,
                 $container->widgetFactory,
@@ -1229,6 +1235,8 @@
                 $container->store,
                 $container->logService,
                 $container->sanitizerService,
+                $container->user,
+                $container->userFactory,
                 $container->dateService,
                 $container->widgetOptionFactory,
                 $container->widgetMediaFactory,

=== modified file 'lib/Widget/ModuleWidget.php'
--- lib/Widget/ModuleWidget.php	2016-03-08 16:54:19 +0000
+++ lib/Widget/ModuleWidget.php	2016-03-17 12:54:49 +0000
@@ -29,9 +29,12 @@
 use Xibo\Factory\DataSetColumnFactory;
 use Xibo\Factory\DataSetFactory;
 use Xibo\Factory\DisplayFactory;
+use Xibo\Factory\DisplayGroupFactory;
+use Xibo\Factory\LayoutFactory;
 use Xibo\Factory\MediaFactory;
 use Xibo\Factory\ModuleFactory;
 use Xibo\Factory\TransitionFactory;
+use Xibo\Factory\WidgetFactory;
 use Xibo\Service\ConfigService;
 use Xibo\Service\ConfigServiceInterface;
 use Xibo\Service\DateServiceInterface;
@@ -144,6 +147,15 @@
      */
     protected $commandFactory;
 
+    /** @var  LayoutFactory */
+    protected $layoutFactory;
+
+    /** @var  WidgetFactory */
+    protected $widgetFactory;
+
+    /** @var  DisplayGroupFactory */
+    protected $displayGroupFactory;
+
     /**
      * ModuleWidget constructor.
      * @param Slim $app
@@ -181,6 +193,19 @@
     }
 
     /**
+     * Set Child Object Dependencies
+     * @param LayoutFactory $layoutFactory
+     * @param WidgetFactory $widgetFactory
+     * @param DisplayGroupFactory $displayGroupFactory
+     */
+    public function setChildObjectDependencies($layoutFactory, $widgetFactory, $displayGroupFactory)
+    {
+        $this->layoutFactory = $layoutFactory;
+        $this->widgetFactory = $widgetFactory;
+        $this->displayGroupFactory = $displayGroupFactory;
+    }
+
+    /**
      * Get the App
      * @return Slim
      */
@@ -811,13 +836,22 @@
     }
 
     /**
+     * Count Library Media
+     * @return int
+     */
+    public function countLibraryMedia()
+    {
+        return 0;
+    }
+
+    /**
      * Get Media Id
      * @return int
      * @throws NotFoundException
      */
     public function getMediaId()
     {
-        $this->getLog()->debug('Getting first MediaID for Widget: %d', $this->getWidgetId());
+        $this->getLog()->debug('Getting first MediaID for Widget: %d. Media: %s', $this->getWidgetId(), json_encode($this->widget->mediaIds));
 
         if (count($this->widget->mediaIds) <= 0)
             throw new NotFoundException(__('No file to return'));
@@ -832,7 +866,9 @@
      */
     public function getMedia()
     {
-        return $this->mediaFactory->getById($this->getMediaId());
+        $media = $this->mediaFactory->getById($this->getMediaId());
+        $media->setChildObjectDependencies($this->layoutFactory, $this->widgetFactory, $this->displayGroupFactory);
+        return $media;
     }
 
     /**

=== modified file 'lib/Xmds/Soap.php'
--- lib/Xmds/Soap.php	2016-03-16 14:15:03 +0000
+++ lib/Xmds/Soap.php	2016-03-17 14:14:04 +0000
@@ -460,7 +460,7 @@
             $layout->loadPlaylists();
 
             // Make sure its XLF is up to date
-            $path = $layout->xlfToDisk();
+            $path = $layout->xlfToDisk(['notify' => false]);
 
             // For layouts the MD5 column is the layout xml
             $fileSize = filesize($path);

=== modified file 'views/layout-designer-page.twig'
--- views/layout-designer-page.twig	2016-02-19 16:41:18 +0000
+++ views/layout-designer-page.twig	2016-03-18 11:01:29 +0000
@@ -31,7 +31,7 @@
 
     <div class="row">
         <div class="col-sm-12 text-center">
-            <h4>{% trans "Layout Design" %} - {{ layout.layout }} {{ isTemplate }}</h4>
+            <h4>{% trans "Layout Design" %} - {{ layout.layout }}</h4>
         </div>
     </div>
     <div class="row">
@@ -39,7 +39,7 @@
             <div class="row">
                 <div class="col-sm-12">
                     {% if isTemplate %}
-                    <div class="alert alert-info">{% trans "Editing a Template will only effect future Layouts." %}</div>
+                    <div class="alert alert-info">{% trans "Editing a Template will only affect future Layouts." %}</div>
                     {% else %}
                     <div id="layout-status" class="alert"></div>
                     {% endif %}

=== modified file 'views/module-form-delete.twig'
--- views/module-form-delete.twig	2015-11-26 12:38:12 +0000
+++ views/module-form-delete.twig	2016-03-17 13:45:09 +0000
@@ -30,7 +30,7 @@
                 {% set message %}{% trans "This action cannot be undone." %}{% endset %}
                 {{ forms.message(message) }}
 
-                {% if module.widget.mediaIds|length > 0 %}
+                {% if module.getModule().regionSpecific == 0 and module.widget.mediaIds|length > 0 %}
                     {% if module.getMedia().isUsed(1) %}
                         {% set message %}{% trans "This widget is linked to Media in the Library which is also in use elsewhere. If this should be deleted then please do so from the Library page." %}{% endset %}
                         {{ forms.message(message) }}

=== modified file 'views/schedule-form-add.twig'
--- views/schedule-form-add.twig	2016-02-23 13:12:37 +0000
+++ views/schedule-form-add.twig	2016-03-17 15:30:45 +0000
@@ -193,9 +193,9 @@
 
                         {% for item in campaigns %}
                             {% if item.isLayoutSpecific == 1 %}
-                                {% set layoutOptions = [{id: item.campaignId, value: item.campaign}]|merge(layoutOptions) %}
+                                {% set layoutOptions = layoutOptions|merge([{id: item.campaignId, value: item.campaign}]) %}
                             {% else %}
-                                {% set campaignOptions = [{id: item.campaignId, value: item.campaign}]|merge(campaignOptions) %}
+                                {% set campaignOptions = campaignOptions|merge([{id: item.campaignId, value: item.campaign}]) %}
                             {% endif %}
                         {% endfor %}
 

=== modified file 'views/schedule-form-edit.twig'
--- views/schedule-form-edit.twig	2016-02-23 13:12:37 +0000
+++ views/schedule-form-edit.twig	2016-03-17 15:30:45 +0000
@@ -192,9 +192,9 @@
 
                         {% for item in campaigns %}
                             {% if item.isLayoutSpecific == 1 %}
-                                {% set layoutOptions = [{id: item.campaignId, value: item.campaign}]|merge(layoutOptions) %}
+                                {% set layoutOptions = layoutOptions|merge([{id: item.campaignId, value: item.campaign}]) %}
                             {% else %}
-                                {% set campaignOptions = [{id: item.campaignId, value: item.campaign}]|merge(campaignOptions) %}
+                                {% set campaignOptions = campaignOptions|merge([{id: item.campaignId, value: item.campaign}]) %}
                             {% endif %}
                         {% endfor %}
 

